function [MTX] = agg2uniqueUPC_fn(MTX,hs,c,Pdev)
%Function AGG2UNIQUE
%Purpose:   Aggregates data with identical UPC codes into one row. 
%           Checks that 99.x% of overlapping price level data is identical,
%           which we take as indication that UPC identifies homogenous
%           items.
%           We then fix data errors in product group and net content data
%           for about 0.5-1.2% of merged data
%           Also (i)checks if Q*P has changed, which should not be the case
%Format:    [MTX] = agg2unique(MTX,hs,c,Pdev)
%Input:     MTX     I*J matrix, where 
%                   I   number of products 
%                   J   structured as [hs(headsize)+T(Q)+T(P)].
%           hs      Number of columns with product characteristics that
%                   preceed data on Q
%           c       hs column on which aggergation is based
%                   (8-UPC, 5-material code)
%           Pdev    max admissible median price difference(in %) over time 
%                   for the product that is being aggregated
%Output:    MTX     I_hat*J aggregated matrix, where I_hat/I is the side of
%                   total aggregation
%           res     1x4 vector with aggregation info:
%                   (i)   unique to total obs for "c" before aggregation, %
%                   (ii)  unique to total obs for "c" after aggregation, %
%                   (iii) max aggregation size
%                   (iv)  decrease in the number of products (I_hat/I), %
%   Rudolfs Bems, Dec 2011

[I,J]=size(MTX);
obs=(J-hs)/2;mx=1;
[uMTXc,m]=unique(MTX(:,c));
rev_pre=nansum(MTX(:,hs+1:hs+obs).*MTX(:,hs+obs+1:hs+2*obs));
repind=find(~ismember(1:I,m));%indexes of non-unique values of col c only
U=0;T=0;P=0;K=0;M=0;
pdispvec=[];
for i=repind
    if ~isnan(MTX(i,c))
        K=K+1;
        iv=find(MTX(:,c)==MTX(i,c));
        %check1: report if units vary
        if nanstd(MTX(iv,7))>1e-8;U=U+1;end
        %check2: report if MCtree group varies
        if nanstd(MTX(iv,2))>1e-8;T=T+1;end
        %check3: report if 'Material' code varies
        if nanstd(MTX(iv,5))>1e-8;M=M+1;end
        %check4: Do not aggregate if prices vary by more than Pdev%
        pdisp=nanmax(MTX(iv,hs+obs+1:hs+2*obs))./nanmin(MTX(iv,hs+obs+1:hs+2*obs));
        if nanmedian(pdisp)>1+(Pdev/100);P=P+1;
            %disp(':-(');disp([nanmax(pdisp) nanmedian(pdisp) nanmin(pdisp)]);
            continue;
        end
        mx=max(mx,length(iv));
        pdispvec=[pdispvec pdisp(~isnan(pdisp))];
        MTX(iv(1),hs+obs+1:hs+2*obs)=nansum(MTX(iv,hs+1:hs+obs).*...
            MTX(iv,hs+obs+1:hs+2*obs))./nansum(MTX(iv,hs+1:hs+obs));
        MTX(iv(1),hs+1:hs+obs)=nansum(MTX(iv,hs+1:hs+obs))./...
            max(~isnan(MTX(iv,hs+1:hs+obs)));
        MTX(iv(1),7)=mode(MTX(iv,7));
        MTX(iv(1),6)=mode(MTX(iv,6));
        MTX(iv(1),2)=mode(MTX(iv,2));
        MTX(iv(2:end),:)=nan(length(iv)-1,2*obs+hs);
    end
end
MTX=MTX(~isnan(MTX(:,c)),:);