function [sumRmtx,inum,minovlp,dvol,dpG,dpF,dpR,dpL,dpP,dpGT,dpT]=pinx_fn(MTX,obs,hs,ti)
%Function PINX
%Purpose:   Computes Laspeyres, Paasche, Fisher and GEKS indexes as well as
%           volume index and revenues using data on P and Q for I products 
%           over T periods. Can handle missing observations
%Format:    [sumRmtx,dvol,dpG,dpF,dpL,dpP]=pinx_fn(MTX,obs,hs,ti)
%Input:     MTX     IxJ matrix, where 
%                   I   number of products 
%                   J   structured as [hs(headsize)+T(Q)+T(P)]. Hence MTX
%                   includes sequentially (i)product charateristics, (ii) 
%                   data on Q and (iii) data on P
%           obs     Number of monthly observations
%           hs      Number of columns with product characteristics that
%                   preceed data on Q and P
%           ti      time intervat (1=m,3=q,12=y)
%Output:    sumRmtx 1xT vector of aggregate revenues
%           inum    1xT vector with number of available items for each t
%           minovlp info about minimum overlap
%           dvol    1xT-1 vector of volume index
%           dpL     1xT-1 vector with Laspeyres index
%           dpP     1xT-1 vector with Paasche index
%           dpF     1xT-1 vector with Fisher index
%           dpG     1xT-1 vector with GEKS index (see Ivancic, Diewert and
%                   Fox (2011), "Scanner data, time aggregation and the
%                   construction of price indexes", J of Econometrics, 161,
%                   24-35.
%   Rudolfs Bems, March 11, 2013

T=floor(obs/ti);

dpL=nan(1,T-1);
dpP=nan(1,T-1);
dpR=nan(1,T-1);
dpF=nan(1,T-1);
dpGT=nan(1,T-1);
dpT=nan(1,T-1);
dpG=nan(1,T-1);
sumRmtx=nan(1,T);
inum=nan(1,T);
minovlp=nan(1,T);
dvol=nan(1,T-1);

% proceed to compute only if there is data
if ~isempty(MTX)==1
    
    I=size(MTX,1);
    P=MTX(:,hs+obs+1:hs+2*obs);
    Q=MTX(:,hs+1:hs+obs);
    Rmtx=Q.*P;
    
    %aggregate revs, Qs and Ps to relevant time interval (ti)
    tempQ=nan(I,T);
    tempR=nan(I,T);
    for t=1:T
        tempQ(:,t)=nansum(Q(:,(t-1)*ti+1:t*ti),2)./...
            max(~isnan(Q(:,(t-1)*ti+1:t*ti)),[],2);
        tempR(:,t)=nansum(Rmtx(:,(t-1)*ti+1:t*ti),2)./...
            max(~isnan(Rmtx(:,(t-1)*ti+1:t*ti)),[],2);
        %"max" is a trick to get nansum(NaN)/max(~isnan(NaN))=0/0=NaN,
        %instead of nansum(NaN)=0
    end
    Q=tempQ;
    Rmtx=tempR;
    P=Rmtx./Q;%Ps backed out from revs and Qs
    
    %Dont compute d(x)'s if all NaNs after aggregation
    if sum(sum(isnan(Q)))==numel(P);return;end
    
    %colect the # of items in each period in a vector
    inum=sum(~isnan(Q),1)./max(~isnan(Q),[],1);%"max" trick
    
    %Check that exp. shares add up
    Smtx=Rmtx./(ones(I,1)*nansum(Rmtx,1));
    if abs(nansum(Smtx,1)-1)>1e-8;disp(':-(');end
    
    %compute Laspeyres, Paasche and Fisher matrixes
    ImtxL=nan(T,T);
    ImtxT=nan(T,T);
    ovlp=nan(T,T);
    Rovlp=nan(T,T);
    for i=1:T
        for j=1:T
            cid=intersect(find(~isnan(P(:,i))),find(~isnan(P(:,j))));
            ovlp(i,j)=length(cid);
            if ~isempty(cid)
                si=Rmtx(cid,i)/sum(Rmtx(cid,i),1);
                sj=Rmtx(cid,j)/sum(Rmtx(cid,j),1);
                ImtxL(i,j)=sum(si.*(P(cid,j)./P(cid,i)),1);
                ImtxT(i,j)=prod((P(cid,j)./P(cid,i)).^(si/2+sj/2));
                Rovlp(i,j)=sum(sum(Rmtx(cid,[i j])));
            else
                ImtxL(i,j)=NaN;
            end
        end
    end
    ImtxP=1./ImtxL';
    ImtxF=(ImtxL.*ImtxP).^0.5;
    minovlp=min(ovlp,[],2)';
    
    %compile chained Laspeyres, Paasche, Fisher and GEKS price changes
    for t=1:T-1
        dpL(t)=ImtxL(t,t+1);
        dpP(t)=ImtxP(t,t+1);
        dpF(t)=ImtxF(t,t+1);
        dpT(t)=ImtxT(t,t+1);
        dpG(t)=prod((ImtxF(t,:)'.*ImtxF(:,t+1)).^(1/T));
        T_adj=(Rovlp(t,:)'+Rovlp(:,t+1))/sum(Rovlp(t,:)'+Rovlp(:,t+1));
        dpGT(t)=prod((ImtxF(t,:)'.*ImtxF(:,t+1)).^T_adj);
    end
    
    %compile Rolling GEKS price index (everything backwards)
    for k=T-12/ti:-1:1%number of rolling windows
        ImtxR=ImtxF(k:k+12/ti,k:k+12/ti);
        for t=12/ti:-1:1%GEKS for each window
            dpR(k+t-1)=prod((ImtxR(t,:)'.*ImtxR(:,t+1)).^(1/(12/ti+1)));
        end
    end
    
    sumRmtx=nansum(Rmtx,1)./max(~isnan(Rmtx),[],1);%"max" trick
    dsumRmtx=sumRmtx(2:end)./sumRmtx(1:end-1);
    dvol=dsumRmtx./dpG;
end
    